@@ -4,14 +4,17 @@
 #ifdef GNOME_ENABLE_DEBUG
 
 #include <sys/time.h>
+#include <glib.h>
 
 #ifdef G_HAVE_ISO_VARARGS
 #define D(...) g_message (__VA_ARGS__)
-#else
+#elif defined(G_HAVE_GNUC_VARARGS)
 #define D(x...) g_message (x)
 #endif
-#define TE() { g_message ("enter %s", __PRETTY_FUNCTION__ ); gdk_threads_enter (); }
-#define TL() { g_message ("leave %s", __PRETTY_FUNCTION__); gdk_threads_leave (); }
+
+#define TE() { g_message ("enter %s", G_STRFUNC); gdk_threads_enter (); }
+#define TL() { g_message ("leave %s", G_STRFUNC); gdk_threads_leave (); }
+
 #define TOTEM_PROFILE(function)     \
     do{                             \
       struct timeval current_time;  \
@@ -22,17 +25,21 @@
       gettimeofday(&current_time, NULL); \
       dtime += current_time.tv_sec + (current_time.tv_usec / 1000000.0); \
       printf("(%s:%d) took %lf seconds\n", \
-	     __PRETTY_FUNCTION__, __LINE__, dtime ); \
+	     G_STRFUNC, __LINE__, dtime ); \
     }while(0)
-#else
+
+#else /* GNOME_ENABLE_DEBUG */
+
 #ifdef G_HAVE_ISO_VARARGS
 #define D(...)
-#else
+#elif defined(G_HAVE_GNUC_VARARGS)
 #define D(x...)
 #endif
+
 #define TE() { gdk_threads_enter (); }
 #define TL() { gdk_threads_leave (); }
 #define TOTEM_PROFILE(function) function
-#endif
+
+#endif /* GNOME_ENABLE_DEBUG */
 
 #endif /* __TOTEM_DEBUG_H__ */
