@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
@@ -67,6 +67,7 @@ typedef struct
 /* strings that we recognize as commands from lirc */
 #define TOTEM_IR_COMMAND_PLAY "play"
 #define TOTEM_IR_COMMAND_PAUSE "pause"
+#define TOTEM_IR_COMMAND_STOP "stop"
 #define TOTEM_IR_COMMAND_NEXT "next"
 #define TOTEM_IR_COMMAND_PREVIOUS "previous"
 #define TOTEM_IR_COMMAND_SEEK_FORWARD "seek_forward"
@@ -124,8 +125,21 @@ totem_lirc_plugin_finalize (GObject *object)
 	G_OBJECT_CLASS (totem_lirc_plugin_parent_class)->finalize (object);
 }
 
+static char *
+totem_lirc_get_url (const char *str)
+{
+	char *s;
+
+	if (str == NULL)
+		return NULL;
+	s = strchr (str, ':');
+	if (s == NULL)
+		return NULL;
+	return g_strdup (s + 1);
+}
+
 static TotemRemoteCommand
-totem_lirc_to_command (const gchar *str)
+totem_lirc_to_command (const gchar *str, char **url)
 {
 	if (strcmp (str, TOTEM_IR_COMMAND_PLAY) == 0)
 		return TOTEM_REMOTE_COMMAND_PLAY;
@@ -133,15 +147,19 @@ totem_lirc_to_command (const gchar *str)
 		return TOTEM_REMOTE_COMMAND_PAUSE;
 	else if (strcmp (str, TOTEM_IR_COMMAND_PLAYPAUSE) == 0)
 		return TOTEM_REMOTE_COMMAND_PLAYPAUSE;
+	else if (strcmp (str, TOTEM_IR_COMMAND_STOP) == 0)
+		return TOTEM_REMOTE_COMMAND_STOP;
 	else if (strcmp (str, TOTEM_IR_COMMAND_NEXT) == 0)
 		return TOTEM_REMOTE_COMMAND_NEXT;
 	else if (strcmp (str, TOTEM_IR_COMMAND_PREVIOUS) == 0)
 		return TOTEM_REMOTE_COMMAND_PREVIOUS;
-	else if (strcmp (str, TOTEM_IR_COMMAND_SEEK_FORWARD) == 0)
+	else if (g_str_has_prefix (str, TOTEM_IR_COMMAND_SEEK_FORWARD) != FALSE) {
+		*url = totem_lirc_get_url (str);
 		return TOTEM_REMOTE_COMMAND_SEEK_FORWARD;
-	else if (strcmp (str, TOTEM_IR_COMMAND_SEEK_BACKWARD) == 0)
+	} else if (g_str_has_prefix (str, TOTEM_IR_COMMAND_SEEK_BACKWARD) != FALSE) {
+		*url = totem_lirc_get_url (str);
 		return TOTEM_REMOTE_COMMAND_SEEK_BACKWARD;
-	else if (strcmp (str, TOTEM_IR_COMMAND_VOLUME_UP) == 0)
+	} else if (strcmp (str, TOTEM_IR_COMMAND_VOLUME_UP) == 0)
 		return TOTEM_REMOTE_COMMAND_VOLUME_UP;
 	else if (strcmp (str, TOTEM_IR_COMMAND_VOLUME_DOWN) == 0)
 		return TOTEM_REMOTE_COMMAND_VOLUME_DOWN;
@@ -185,7 +203,7 @@ static gboolean
 totem_lirc_read_code (GIOChannel *source, GIOCondition condition, TotemLircPlugin *pi)
 {
 	char *code;
-	char *str = NULL;
+	char *str = NULL, *url = NULL;
 	int ok;
 	TotemRemoteCommand cmd;
 
@@ -215,9 +233,10 @@ totem_lirc_read_code (GIOChannel *source, GIOCondition condition, TotemLircPlugi
 			break;
 		}
 
-		cmd = totem_lirc_to_command (str);
+		cmd = totem_lirc_to_command (str, &url);
 
-		totem_action_remote (pi->totem, cmd, NULL);
+		totem_action_remote (pi->totem, cmd, url);
+		g_free (url);
 	} while (TRUE);
 
 	g_free (code);
@@ -231,6 +250,7 @@ impl_activate (TotemPlugin *plugin,
 	       GError **error)
 {
 	TotemLircPlugin *pi = TOTEM_LIRC_PLUGIN (plugin);
+	char *path;
 	int fd;
 
 	pi->totem = g_object_ref (totem);
@@ -242,12 +262,19 @@ impl_activate (TotemPlugin *plugin,
 		return FALSE;
 	}
 
-	if (lirc_readconfig (NULL, &pi->lirc_config, NULL) == -1) {
+	/* Load the default Totem setup */
+	path = totem_plugin_find_file (plugin, "totem_lirc_default");
+	if (path == NULL || lirc_readconfig (path, &pi->lirc_config, NULL) == -1) {
+		g_free (path);
 		g_set_error (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
-				_("Couldn't read lirc configuration."));
+			     _("Couldn't read lirc configuration."));
 		close (fd);
 		return FALSE;
 	}
+	g_free (path);
+
+	/* Load the user config, doesn't matter if it's not there */
+	lirc_readconfig (NULL, &pi->lirc_config, NULL);
 
 	pi->lirc_channel = g_io_channel_unix_new (fd);
 	g_io_channel_set_encoding (pi->lirc_channel, NULL, NULL);
